
import java.awt.event.*;
import java.util.*;
import java.awt.*;
/** The GUI for a simple text field display of the temperature,
 *  as well as buttons to manipulate it.
 */
class FarenheitGUI  implements java.util.Observer
{
    private Frame temperatureFrame;
    private String label;   
    private TemperatureModel model;
    private TextField display = new TextField();
    private Button upButton = new Button("Raise");
    private Button downButton = new Button("Lower");
    private Button setButton = new Button("Set");

    /** Construct the gui, using the model and a position on the display */
    FarenheitGUI(TemperatureModel model, int h, int v)
    {   
        this.label = label;
        this.model = model;
        model.addObserver(this); // Connect the View to the Model

        /* Init the graphical elements */
        temperatureFrame = new Frame("Temperature");
        temperatureFrame.add("North", new Label(label));
        temperatureFrame.add("Center", display);
        Panel buttons = new Panel();
        buttons.add(upButton);
        buttons.add(downButton);        
        buttons.add(setButton);
        upButton.setActionCommand("up");
        downButton.setActionCommand("down");
        setButton.setActionCommand("set");

        temperatureFrame.add("South", buttons);     
        temperatureFrame.addWindowListener(new CloseListener());        
        temperatureFrame.setSize(200, 100);
        temperatureFrame.setLocation(h, v);
        temperatureFrame.setVisible(true);
        /* set the initial temperature */
        setDisplay(""+model.getF());
        /* Provide a listener to handle button actions */
        addListener(new MyListener());
    }
    /* Set the text field value */
    public void setDisplay(String s)
    { 
        display.setText(s);
    }
    /* Accessor to the text field value */
    public double getDisplay()
    {
        double result = 0.0;
        try
        {   
            result = Double.valueOf(display.getText()).doubleValue();
        }
        catch (NumberFormatException ex)
        {
            ex.printStackTrace();
        }
        return result;
    }
    /* Add a listener for each button */
    public void addListener(ActionListener a)
    {   
        setButton.addActionListener(a);
        upButton.addActionListener(a);
        downButton.addActionListener(a);
    }
    /* Handle window close button */
    public static class CloseListener extends WindowAdapter
    {   public void windowClosing(WindowEvent e)
        {   
            e.getWindow().setVisible(false);
            System.exit(0);
        }
    }
    
    /** Have the display update itself when notified by the model */
    public void update(Observable t, Object o) 
    {   
        setDisplay("" + model.getF());
    }
    
    /** The actions to be performed for each button */
    class MyListener implements ActionListener
    {   public void actionPerformed(ActionEvent e)
        {   
            // Raise button pressed
            if (e.getActionCommand().equals("up"))
            {
                model.increment();
            }
            // Lower button pressed
            if (e.getActionCommand().equals("down"))
            {
                model.decrement();
            }
            // Set button pressed             
            if (e.getActionCommand().equals("set"))
            {
                model.setF(getDisplay());
            }
        }
    }
    
    
}
